@@ -46,7 +46,8 @@ struct _EdgePosClass {
 
 GType edge_pos_get_type (void) G_GNUC_CONST;
 
-GtkWidget *edge_widget_new (int screen,
+GtkWidget *edge_widget_new (gchar *panel_id,
+			    int screen,
 			    BorderEdge edge,
 			    BasePMode mode,
 			    BasePState state,
@@ -56,7 +57,7 @@ GtkWidget *edge_widget_new (int screen,
 			    PanelBackType back_type,
 			    char *back_pixmap,
 			    gboolean fit_pixmap_bg,
-			    gboolean strech_pixmap_bg,
+			    gboolean stretch_pixmap_bg,
 			    gboolean rotate_pixmap_bg,
 			    GdkColor *back_color);
 
